package Task::BeLike::GENEHACK;
our $AUTHORITY = 'cpan:GENEHACK';
# ABSTRACT: individuality via conformity
$Task::BeLike::GENEHACK::VERSION = '0.402';
use strict;
use warnings;
use 5.010;


1;

__END__

=pod

=encoding UTF-8

=head1 NAME

Task::BeLike::GENEHACK - individuality via conformity

=head1 VERSION

version 0.402

=head1 TASK CONTENTS

=head2 Modules I use

=head3 L<App::MiseEnPlace>

=head3 L<App::cpanminus>

=head3 L<App::cpanoutdated>

=head3 L<Audio::M4P::QuickTime>

=head3 L<DBD::SQLite>

=head3 L<Data::Dump::Streamer>

=head3 L<DateTime::Tiny>

=head3 L<Dist::Zilla::App::Command::cover>

=head3 L<Dist::Zilla::PluginBundle::GENEHACK>

=head3 L<Imager>

=head3 L<List::MoreUtils>

=head3 L<Modern::Perl>

=head3 L<Module::CoreList>

=head3 L<Module::Install>

=head3 L<Module::Which>

=head3 L<Moose>

=head3 L<MooseX::App::Cmd>

=head3 L<MooseX::Declare>

=head3 L<MooseX::amine>

=head3 L<Path::Tiny>

=head3 L<Perl::Tidy>

=head3 L<Pod::Coverage::TrustPod>

=head3 L<Task::Catalyst>

=head3 L<Test::Class>

=head3 L<Test::Exception>

=head3 L<Test::MockObject::Extends>

=head3 L<Test::Most>

=head3 L<Test::Pod>

=head3 L<Test::Pod::Coverage>

=head3 L<Text::Xslate>

=head3 L<Try::Tiny>

=head3 L<XML::LibXML>

=head3 L<XML::Simple>

=head3 L<XML::Writer>

=head3 L<YAML>

=head3 L<YAML::XS>

=head3 L<autodie>

=head3 L<local::lib>

=head3 L<namespace::autoclean>

=head1 AUTHOR

John SJ Anderson <john@genehack.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2020 by John SJ Anderson.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
